==> aster-full-src-7.4.0-4.tar.gz: STA7.4/bibfor/modelisa/ata000.f <==
      SUBROUTINE ATA000(AZ,NUMEDZ,RTBLOC,ATAZ,BASEZ,NBLIG)

C.======================================================================
C            CONFIGURATION MANAGEMENT OF EDF VERSION
C MODIF MODELISA  DATE 02/11/2004   AUTEUR MABBAS M.ABBAS 
C ======================================================================
C COPYRIGHT (C) 1991 - 2001  EDF R&D                  WWW.CODE-ASTER.ORG
C THIS PROGRAM IS FREE SOFTWARE; YOU CAN REDISTRIBUTE IT AND/OR MODIFY
C IT UNDER THE TERMS OF THE GNU GENERAL PUBLIC LICENSE AS PUBLISHED BY
C THE FREE SOFTWARE FOUNDATION; EITHER VERSION 2 OF THE LICENSE, OR   
C (AT YOUR OPTION) ANY LATER VERSION.                                 
C
C THIS PROGRAM IS DISTRIBUTED IN THE HOPE THAT IT WILL BE USEFUL, BUT 
C WITHOUT ANY WARRANTY; WITHOUT EVEN THE IMPLIED WARRANTY OF          
C MERCHANTABILITY OR FITNESS FOR A PARTICULAR PURPOSE. SEE THE GNU    
C GENERAL PUBLIC LICENSE FOR MORE DETAILS.                            
C
C YOU SHOULD HAVE RECEIVED A COPY OF THE GNU GENERAL PUBLIC LICENSE   
C ALONG WITH THIS PROGRAM; IF NOT, WRITE TO EDF R&D CODE_ASTER,       
C    1 AVENUE DU GENERAL DE GAULLE, 92141 CLAMART CEDEX, FRANCE.      
C ======================================================================
      IMPLICIT      NONE
      CHARACTER*(*) AZ
      CHARACTER*(*) NUMEDZ
      CHARACTER*(*) ATAZ
      CHARACTER*(*) BASEZ
      REAL*8        RTBLOC
      INTEGER       NBLIG

C
C ----------------------------------------------------------------------
C ROUTINE APPELEE PAR : ALGOCP/FROGDP/FROLGD/FROPGD
C ----------------------------------------------------------------------
C
C  LE BUT DE CETTE ROUTINE EST DE CREER LA MATR_ASSE DE NOM ATA.
C
C  LE .VALE DE CETTE MATR_ASSE VA CONTENIR LES TERMES DU PRODUIT 
C  DE MATRICES AT*A.
C  * A EST 'CONCEPTUELLEMENT' UNE MATRICE RECTANGLE DE 'HAUTEUR' NBLIG 
C    ET DE LARGEUR NEQ.
C  * A EST 'INFORMATIQUEMENT' UNE COLLECTION NUMEROTEE COMPORTANT NBLIG
C    OBJETS QUI SONT DES VECTEURS DE REELS DE LONGUEUR NEQ.
C  CHACUN DE CES VECTEURS EST UNE LIGNE DE LA MATRICE A.
C  LA MATR_ASSE ATA VA DONC ETRE SYMETRIQUE ET A VALEURS REELLES. 
C  D'AUTRE PART ON VA LUI AFFECTER LE PROFIL CORRESPONDANT AU NUMEDDL
C  NUMEDZ QUI EST SOIT EN LIGNE DE CIEL, SOIT EN MORSE.
C
C  C'EST UNE ROUTINE CHAPEAU QUI APPELLE
C  .ATASMO DANS LE CAS D'UN STOCKAGE MORSE
C  .ATASL2 DANS LE CAS D'UN STOCKAGE EN LIGNE DE CIEL
C                       
C
C IN  AZ     : NOM DE LA COLLECTION DES VECTEURS LIGNES (I.E. AZ EST 
C              LA MATRICE RECTANGULAIRE POUR LAQUELLE ON VA CALCULER
C              LE PRODUIT AZ_T*AZ).
C IN  NUMEDZ : NOM DU NUME_DDL DECRIVANT LES LIGNES DE LA MATRICE AZ
C IN  RTBLOC : TAILLE DES BLOCS DE LA MATR_ASSE.
C OUT ATAZ   : NOM DE LA MATR_ASSE SYMETRIQUE A VALEURS REELLES 
C              DONT LE .VALE CONTIENT LE PRODUIT AT*A.
C              CE PROFIL EST DETERMINE DANS LA ROUTINE.
C IN  BASEZ  : NOM DE LA BASE SUR LAQUELLE ON CREE LA MATR_ASSE.
C IN  NBLIG  : NOMBRE DE LIGNES DE LA MATRICE AZ
C
C --- DEBUT DECLARATIONS NORMALISEES JEVEUX ---------------------------
C
      INTEGER            ZI
      COMMON  / IVARJE / ZI(1)
      REAL*8             ZR
      COMMON  / RVARJE / ZR(1)
      COMPLEX*16         ZC
      COMMON  / CVARJE / ZC(1)
      LOGICAL            ZL
      COMMON  / LVARJE / ZL(1)
      CHARACTER*8        ZK8
      CHARACTER*16                ZK16
      CHARACTER*24                          ZK24
      CHARACTER*32                                    ZK32
      CHARACTER*80                                              ZK80
      COMMON  / KVARJE / ZK8(1) , ZK16(1) , ZK24(1) , ZK32(1) , ZK80(1)
      CHARACTER*32       JEXNUM , JEXNOM
C
C ---------- FIN  DECLARATIONS  NORMALISEES  JEVEUX --------------------
C
      INTEGER   IRET
C
C ----------------------------------------------------------------------
C
      CALL JEEXIN(NUMEDZ(1:14)//'.SLCS.REFE',IRET)
      IF (IRET.EQ.0) THEN
        CALL JEEXIN(NUMEDZ(1:14)//'.SMOS.REFE',IRET)
        IF (IRET.EQ.0) THEN
          CALL UTMESS('F','ATA000','IMPOSSIBILITE, LE NUME_DDL '//
     +                NUMEDZ(1:14)//' NE CORRESPOND NI A UN STOCKAGE '//
     +               'MORSE, NI A UN STOCKAGE EN LIGNE DE CIEL .')
        ELSE
          CALL ATASMO ( AZ, NUMEDZ, RTBLOC, ATAZ, BASEZ, NBLIG )
        ENDIF
      ELSE
        CALL ATALC2 ( AZ, NUMEDZ, RTBLOC, ATAZ, BASEZ, NBLIG )      
      ENDIF
C
      END

==> aster-full-src-8.1.0-1.tar.gz: STA8.1/bibfor/modelisa/ata000.f <==
      SUBROUTINE ATA000(AZ,NUMEDZ,RTBLOC,ATAZ,BASEZ,NBLIG)

C.======================================================================
C            CONFIGURATION MANAGEMENT OF EDF VERSION
C MODIF MODELISA  DATE 18/04/2005   AUTEUR VABHHTS J.PELLET 
C ======================================================================
C COPYRIGHT (C) 1991 - 2001  EDF R&D                  WWW.CODE-ASTER.ORG
C THIS PROGRAM IS FREE SOFTWARE; YOU CAN REDISTRIBUTE IT AND/OR MODIFY
C IT UNDER THE TERMS OF THE GNU GENERAL PUBLIC LICENSE AS PUBLISHED BY
C THE FREE SOFTWARE FOUNDATION; EITHER VERSION 2 OF THE LICENSE, OR
C (AT YOUR OPTION) ANY LATER VERSION.
C
C THIS PROGRAM IS DISTRIBUTED IN THE HOPE THAT IT WILL BE USEFUL, BUT
C WITHOUT ANY WARRANTY; WITHOUT EVEN THE IMPLIED WARRANTY OF
C MERCHANTABILITY OR FITNESS FOR A PARTICULAR PURPOSE. SEE THE GNU
C GENERAL PUBLIC LICENSE FOR MORE DETAILS.
C
C YOU SHOULD HAVE RECEIVED A COPY OF THE GNU GENERAL PUBLIC LICENSE
C ALONG WITH THIS PROGRAM; IF NOT, WRITE TO EDF R&D CODE_ASTER,
C    1 AVENUE DU GENERAL DE GAULLE, 92141 CLAMART CEDEX, FRANCE.
C ======================================================================
      IMPLICIT      NONE
      CHARACTER*(*) AZ
      CHARACTER*(*) NUMEDZ
      CHARACTER*(*) ATAZ
      CHARACTER*(*) BASEZ
      REAL*8        RTBLOC
      INTEGER       NBLIG

C
C ----------------------------------------------------------------------
C ROUTINE APPELEE PAR : ALGOCP/FROGDP/FROLGD/FROPGD
C ----------------------------------------------------------------------
C
C  LE BUT DE CETTE ROUTINE EST DE CREER LA MATR_ASSE DE NOM ATA.
C
C  LE .VALE DE CETTE MATR_ASSE VA CONTENIR LES TERMES DU PRODUIT
C  DE MATRICES AT*A.
C  * A EST 'CONCEPTUELLEMENT' UNE MATRICE RECTANGLE DE 'HAUTEUR' NBLIG
C    ET DE LARGEUR NEQ.
C  * A EST 'INFORMATIQUEMENT' UNE COLLECTION NUMEROTEE COMPORTANT NBLIG
C    OBJETS QUI SONT DES VECTEURS DE REELS DE LONGUEUR NEQ.
C  CHACUN DE CES VECTEURS EST UNE LIGNE DE LA MATRICE A.
C  LA MATR_ASSE ATA VA DONC ETRE SYMETRIQUE ET A VALEURS REELLES.
C  D'AUTRE PART ON VA LUI AFFECTER LE PROFIL CORRESPONDANT AU NUMEDDL
C  NUMEDZ QUI EST SOIT EN LIGNE DE CIEL, SOIT EN MORSE.
C
C  C'EST UNE ROUTINE CHAPEAU QUI APPELLE
C  .ATASMO DANS LE CAS D'UN STOCKAGE MORSE
C  .ATASL2 DANS LE CAS D'UN STOCKAGE EN LIGNE DE CIEL
C
C
C IN  AZ     : NOM DE LA COLLECTION DES VECTEURS LIGNES (I.E. AZ EST
C              LA MATRICE RECTANGULAIRE POUR LAQUELLE ON VA CALCULER
C              LE PRODUIT AZ_T*AZ).
C IN  NUMEDZ : NOM DU NUME_DDL DECRIVANT LES LIGNES DE LA MATRICE AZ
C IN  RTBLOC : TAILLE DES BLOCS DE LA MATR_ASSE.
C OUT ATAZ   : NOM DE LA MATR_ASSE SYMETRIQUE A VALEURS REELLES
C              DONT LE .VALE CONTIENT LE PRODUIT AT*A.
C              CE PROFIL EST DETERMINE DANS LA ROUTINE.
C IN  BASEZ  : NOM DE LA BASE SUR LAQUELLE ON CREE LA MATR_ASSE.
C IN  NBLIG  : NOMBRE DE LIGNES DE LA MATRICE AZ
C
C --- DEBUT DECLARATIONS NORMALISEES JEVEUX ---------------------------
C
      INTEGER            ZI
      COMMON  / IVARJE / ZI(1)
      REAL*8             ZR
      COMMON  / RVARJE / ZR(1)
      COMPLEX*16         ZC
      COMMON  / CVARJE / ZC(1)
      LOGICAL            ZL
      COMMON  / LVARJE / ZL(1)
      CHARACTER*8        ZK8
      CHARACTER*16                ZK16
      CHARACTER*24                          ZK24
      CHARACTER*32                                    ZK32
      CHARACTER*80                                              ZK80
      COMMON  / KVARJE / ZK8(1) , ZK16(1) , ZK24(1) , ZK32(1) , ZK80(1)
      CHARACTER*32       JEXNUM , JEXNOM
C
C ---------- FIN  DECLARATIONS  NORMALISEES  JEVEUX --------------------
C
      INTEGER   IRET
C
C ----------------------------------------------------------------------
C
      CALL JEEXIN(NUMEDZ(1:14)//'.SLCS.REFE',IRET)
      IF (IRET.EQ.0) THEN
        CALL JEEXIN(NUMEDZ(1:14)//'.SMOS.REFE',IRET)
        IF (IRET.EQ.0) THEN
          CALL UTMESS('F','ATA000','IMPOSSIBILITE, LE NUME_DDL '//
     +                NUMEDZ(1:14)//' NE CORRESPOND NI A UN STOCKAGE '//
     +               'MORSE, NI A UN STOCKAGE EN LIGNE DE CIEL .')
        ELSE
          CALL ATASMO ( AZ, NUMEDZ, ATAZ, BASEZ, NBLIG)
        ENDIF
      ELSE
        CALL ATALC2 ( AZ, NUMEDZ, RTBLOC, ATAZ, BASEZ, NBLIG )
      ENDIF
C
      END
